import * as react from 'react';
import { CSSProperties } from 'react';
import { Token as Token$1 } from 'prismjs';
import * as prismjs from 'prismjs';
export { prismjs as Prism };

type Language = string;
type PrismGrammar = Record<string, unknown>;
type LanguagesDict = Record<Language, PrismGrammar>;
type PrismLib = {
    languages: LanguagesDict;
    tokenize: (code: string, grammar: PrismGrammar) => Array<Token$1 | string>;
    highlight: (code: string, grammar: PrismGrammar, language: Language) => string;
    hooks: {
        run: (name: string, env: {
            code: string;
            grammar: PrismGrammar;
            language: Language;
        }) => void;
    };
};
type Token = {
    types: string[];
    content: string;
    empty?: boolean;
};
type StyleObj = CSSProperties;
type LineInputProps = {
    style?: StyleObj;
    className?: string;
    line: Token[];
    [key: string]: unknown;
};
type LineOutputProps = {
    style?: StyleObj;
    className: string;
    [key: string]: unknown;
};
type TokenInputProps = {
    style?: StyleObj;
    className?: string;
    token: Token;
    [key: string]: unknown;
};
type TokenOutputProps = {
    style?: StyleObj;
    className: string;
    children: string;
    [key: string]: unknown;
};
type InternalHighlightProps = {
    prism: PrismLib;
    theme: PrismTheme;
    language: Language;
    code: string;
    children: (props: RenderProps) => JSX.Element;
};
type HighlightProps = {
    prism?: PrismLib;
    theme?: PrismTheme;
    language: Language;
    code: string;
    children: (props: RenderProps) => JSX.Element;
};
type RenderProps = {
    tokens: Token[][];
    className: string;
    style: CSSProperties;
    getLineProps: (input: LineInputProps) => LineOutputProps;
    getTokenProps: (input: TokenInputProps) => TokenOutputProps;
};
type PrismThemeEntry = {
    color?: string;
    cursor?: string;
    background?: string;
    backgroundImage?: string;
    backgroundColor?: string;
    textShadow?: string;
    fontStyle?: "normal" | "italic";
    fontWeight?: "normal" | "bold" | "100" | "200" | "300" | "400" | "500" | "600" | "700" | "800" | "900";
    textDecorationLine?: "none" | "underline" | "line-through" | "underline line-through";
    opacity?: number;
};
type PrismTheme = {
    plain: PrismThemeEntry;
    styles: Array<{
        types: string[];
        style: PrismThemeEntry;
        languages?: Language[];
    }>;
};

declare const theme$f: PrismTheme;

declare const theme$e: PrismTheme;

declare const theme$d: PrismTheme;

declare const theme$c: PrismTheme;

declare const theme$b: PrismTheme;

declare const theme$a: PrismTheme;

declare const theme$9: PrismTheme;

declare const theme$8: PrismTheme;

declare const theme$7: PrismTheme;

declare const theme$6: PrismTheme;

declare const theme$5: PrismTheme;

declare const theme$4: PrismTheme;

declare const theme$3: PrismTheme;

declare const theme$2: PrismTheme;

declare const theme$1: PrismTheme;

declare const theme: PrismTheme;

declare namespace index {
  export {
    theme$f as dracula,
    theme$e as duotoneDark,
    theme$d as duotoneLight,
    theme$c as github,
    theme$1 as jettwaveDark,
    theme as jettwaveLight,
    theme$b as nightOwl,
    theme$a as nightOwlLight,
    theme$9 as oceanicNext,
    theme$8 as okaidia,
    theme$7 as palenight,
    theme$6 as shadesOfPurple,
    theme$5 as synthwave84,
    theme$4 as ultramin,
    theme$3 as vsDark,
    theme$2 as vsLight,
  };
}

/**
 * Prism React Renderer requires this specific instance
 * of Prism provided to ensure the languages are correctly loaded
 */
declare const Highlight: (props: HighlightProps) => react.FunctionComponentElement<InternalHighlightProps>;

export { Highlight, index as themes };
